{% extends template_to_extend %}

{% block extra_head %}
	<meta name="keywords" content="{{ page.seo_description }}" />
	<meta name="description" content="{{ page.seo_keywords }}" />
{% endblock %}
{% block title %}{{ page.title }}{% endblock %}

{% block infoslabel %}
	{% include "alapage/edit_btn.html" %}
{% endblock %}
{% block content %}
	{% if page.content %}{{ page.content|safe }}{% endif %}
{% endblock %}